#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai
version:              3.2.3
visibility:           public
id:                   wai-3.2.3-6qGX6clG5kmJXJyRZI2UzB
key:                  wai-3.2.3-6qGX6clG5kmJXJyRZI2UzB
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  f0de726df75cca16af2547651a4ef2c2
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/wai-3.2.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wai-3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/wai-3.2.3
hs-libraries:         HSwai-3.2.3-6qGX6clG5kmJXJyRZI2UzB
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    http-types-0.12.3-Di0Av9jbzuQGAtr7LDgLEc
    network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd text-1.2.4.1
    vault-0.3.1.5-JuhHFgRQKzq7w11JAilddt

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

